<?php

/**
* The public-facing functionality of the plugin.
*
* @link 		https://entusiastics.com
* @since 		1.0.0
*
* @package 	Entusiastics_Quiz_Game
* @subpackage 	Entusiastics_Quiz_Game/public
*/

class Entusiastics_Quiz_Game_Public {

	/**
	 * The plugin options.
	 *
	 * @since 		1.0.0
	 * @access 		private
	 * @var 		string 			$options    The plugin options.
	 */
	private $options;

	/**
	 * The ID of this plugin.
	 *
	 * @since 		1.0.0
	 * @access 		private
	 * @var 		string 			$plugin_name 		The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since 		1.0.0
	 * @access 		private
	 * @var 		string 			$version 			The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since 		1.0.0
	 * @param 		string 			$Entusiastics_Quiz_Game 	The name of the plugin.
	 * @param 		string 			$version 			The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

		define( 'ENTUSIASTICS_QUIZ_GAME_PUBLIC_URL', plugin_dir_url( __FILE__ ));

		$this->set_options();
	}

	/**
	 * Add custom class to body if the template is main template
	 *
	 * @since 		1.0.0
	 */
	public function entusiastics_quiz_game_add_template_body_custom_class( $classes ) {
		
		global $post;

		$classes[] = '';
		
		if ($post->post_type == "quizz"){
		    $classes[] = 'entusiastics-quiz-game-template';
		}
		
		return $classes;
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since 		1.0.0
	 */
	public function enqueue_styles() {

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/'.$this->plugin_name.'-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since 		1.0.0
	 */
	public function enqueue_scripts() {

		wp_register_script( $this->plugin_name.'-main', plugin_dir_url( __FILE__ ) . 'js/'.$this->plugin_name.'-public.js', array( 'jquery' ), $this->version, true );

		$translated_form_strings = array(
			'admin_url' => admin_url('admin-ajax.php'),
			'shortcode_url' => entusiastics_quiz_game_get_url_shortcode_landing()
		);

		wp_localize_script( $this->plugin_name.'-main', 'translated_strings', $translated_form_strings );

		wp_enqueue_script( $this->plugin_name.'-main' );
		
	}

	/**
	 * Processes shortcode entusiastics-quiz-game
	 *
	 * @param   array	$atts		The attributes from the shortcode
	 *
	 * @uses	get_option
	 * @uses	get_layout
	 *
	 * @return	mixed	$output		Output of the buffer
	 */
	public function add_entusiastics_quiz_shortcode($atts = array()) {

		if (is_admin()){ return; }

		global $wpdb;

		$quiz_id = $atts[0];
		$data = [];

		if(empty($quiz_id) or !is_numeric($quiz_id)) {

			$data['error'] = '3';

			do_action('entusiastics_show_notfound_template', 'quiz-not_found', $data);

		} else {

			$data = QuizzesController::display($quiz_id);
		}

		ob_start();

		if($data['error'] != '' && $data['error'] != 2) {

			do_action('entusiastics_show_notfound_template', 'quiz-not_found', $data);

		} else {

			do_action('entusiastics_show_quiz_template', 'quiz', $data);

		}

		$content = ob_get_clean();

		return $content;

	} // add_entusiastics_quiz_shortcode()


	/**
	 * Processes shortcode entusiastics-quiz-game
	 *
	 * @param   array	$atts		The attributes from the shortcode
	 *
	 * @uses	get_option
	 * @uses	get_layout
	 *
	 * @return	mixed	$output		Output of the buffer
	 */
	public function add_entusiastics_latest_quizzes_shortcode($atts = array()) {

		if (is_admin()){ return; }

		global $wpdb;

		$data = [];
		$order_by = 'created_at';

		$sql = $wpdb->prepare("SELECT * FROM ".ENTUSIASTICS_QUIZ_GAME_QUIZZES." ORDER BY %s", $order_by);
		$quizzes = $wpdb->get_results($sql);

		ob_start();

		if(empty($quizzes)) {

			$data['error'] = 1;

			do_action('entusiastics_show_notfound_template', 'quiz-not_found', $data);

		} else {

			do_action('entusiastics_show_latest_quizzes_template', 'quiz-latest_quizzes', $quizzes);

		}

		$content = ob_get_clean();

		return $content;

	} // add_entusiastics_latest_quizzes_shortcode()

	/**
	 * Registers all shortcodes at once
	 *
	 * @return [type] [description]
	 */
	public function register_shortcodes() {
		add_shortcode('entusiastics-latest-quizzes', array( $this, 'add_entusiastics_latest_quizzes_shortcode'));
		add_shortcode('entusiastics-quiz-game', array( $this, 'add_entusiastics_quiz_shortcode'));
	} // register_shortcodes()
	

	/**
	 * Adds a default single view template for a quiz opening
	 *
	 * @param 	string 		$template 		The name of the template
	 * @return 	mixed 						The single template
	 */
	public function single_cpt_template( $template ) {

		global $post;

		$return = $template;

		return $return;

	} // single_cpt_template()

	/**
	 * Sets the class variable $options
	 */
	private function set_options() {

		$this->options = get_option( $this->plugin_name . '-options' );

	} // set_options()

} // class
